@@ -21,6 +21,8 @@ import (
 	"github.com/ulikunitz/xz"
 )
 
+const TableQuery = "SELECT * FROM"
+
 // Cli wraps stdout and error output specification.
 type Cli struct {
 	// OutStream is the output destination.
@@ -69,6 +71,7 @@ func (cli Cli) Run(args []string) int {
 		queryFile string
 		analyze   string
 		onlySQL   string
+		tableName string
 
 		inFlag      inputFlag
 		inDelimiter string
@@ -107,6 +110,7 @@ func (cli Cli) Run(args []string) int {
 	flags.StringVar(&queryFile, "q", "", "read query from the specified file.")
 	flags.StringVar(&analyze, "a", "", "analyze the file and suggest SQL.")
 	flags.StringVar(&onlySQL, "A", "", "analyze the file but only suggest SQL.")
+	flags.StringVar(&tableName, "t", "", "read table name from the specified file.")
 	flags.BoolVar(&usage, "help", false, "display usage information.")
 	flags.BoolVar(&version, "version", false, "display version information.")
 	flags.BoolVar(&Debug, "debug", false, "debug print.")
@@ -204,7 +208,7 @@ func (cli Cli) Run(args []string) int {
 		return 0
 	}
 
-	query, err := getQuery(flags.Args(), queryFile)
+	query, err := getQuery(flags.Args(), tableName, queryFile)
 	if err != nil {
 		log.Printf("ERROR: %s", err)
 		return 1
@@ -312,7 +316,7 @@ func (cli Cli) Run(args []string) int {
 // Usage is outputs usage information.
 func Usage(flags *flag.FlagSet) {
 	bold := gchalk.Bold
-	fmt.Fprintf(flags.Output(), "%s - Execute SQL queries on CSV, LTSV, JSON and TBLN.\n\n", trdsql.AppName)
+	fmt.Fprintf(flags.Output(), "%s - Execute SQL queries on CSV, LTSV, JSON, YAML and TBLN.\n\n", trdsql.AppName)
 	fmt.Fprintf(flags.Output(), "%s\n", bold("Usage"))
 	fmt.Fprintf(flags.Output(), "\t%s [OPTIONS] [SQL(SELECT...)]\n\n", trdsql.AppName)
 
@@ -424,12 +428,20 @@ func trimQuery(query string) string {
 	return strings.TrimRight(strings.TrimSpace(query), ";")
 }
 
-func getQuery(args []string, fileName string) (string, error) {
-	if fileName == "" {
+func getQuery(args []string, tableName string, queryFile string) (string, error) {
+	if tableName != "" {
+		var query strings.Builder
+		query.WriteString(TableQuery)
+		query.WriteString(" ")
+		query.WriteString(tableName)
+		return trimQuery(query.String()), nil
+	}
+
+	if queryFile == "" {
 		return trimQuery(strings.Join(args, " ")), nil
 	}
 
-	sqlByte, err := os.ReadFile(fileName)
+	sqlByte, err := os.ReadFile(queryFile)
 	if err != nil {
 		return "", err
 	}
@@ -569,27 +581,9 @@ func outGuessFormat(fileName string) trdsql.Format {
 			return trdsql.CSV
 		}
 		ext := strings.ToUpper(strings.TrimLeft(dotExt, "."))
-		switch ext {
-		case "CSV":
-			return trdsql.CSV
-		case "LTSV":
-			return trdsql.LTSV
-		case "JSON":
-			return trdsql.JSON
-		case "TBLN":
-			return trdsql.TBLN
-		case "RAW":
-			return trdsql.RAW
-		case "MD":
-			return trdsql.MD
-		case "AT":
-			return trdsql.AT
-		case "VF":
-			return trdsql.VF
-		case "JSONL":
-			return trdsql.JSONL
-		case "YAML", "YML":
-			return trdsql.YAML
+		format := trdsql.OutputFormat(ext)
+		if format != trdsql.GUESS {
+			return format
 		}
 		fileName = fileName[0 : len(fileName)-len(dotExt)]
 	}
