@@ -8,17 +8,6 @@ import (
 	"io"
 	"log"
 	"strings"
-
-	// MySQL driver.
-	_ "github.com/go-sql-driver/mysql"
-
-	// PostgreSQL driver.
-	_ "github.com/lib/pq"
-
-	// SQLite3 driver.
-	_ "github.com/mattn/go-sqlite3"
-	// SQlite3 extension library.
-	sqlite3_stdlib "github.com/multiprocessio/go-sqlite3-stdlib"
 )
 
 var (
@@ -55,42 +44,6 @@ type DB struct {
 	importCount int
 }
 
-func init() {
-	// Enable sqlite3 extensions.
-	// It can be used by setting the driver to "sqlite3_ext".
-	sqlite3_stdlib.Register("sqlite3_ext")
-}
-
-// Connect is connects to the database.
-// Currently supported drivers are sqlite3, mysql, postgres.
-// Set quote character and maxBulk depending on the driver type.
-func Connect(driver, dsn string) (*DB, error) {
-	sqlDB, err := sql.Open(driver, dsn)
-	if err != nil {
-		return nil, err
-	}
-
-	db := &DB{
-		DB:     sqlDB,
-		driver: driver,
-		dsn:    dsn,
-	}
-	debug.Printf("driver: %s, dsn: %s", driver, dsn)
-
-	switch driver {
-	case "sqlite3", "sqlite3_ext":
-		db.quote = "`"
-		db.maxBulk = 500
-	case "mysql":
-		db.quote = "`"
-		db.maxBulk = 1000
-	case "postgres":
-		db.quote = "\""
-	}
-
-	return db, nil
-}
-
 // Disconnect is disconnect the database.
 func (db *DB) Disconnect() error {
 	return db.Close()
@@ -251,7 +204,11 @@ func (db *DB) insertImport(ctx context.Context, table *importTable, reader Reade
 	var stmt *sql.Stmt
 	defer db.stmtClose(stmt)
 
-	table.maxCap = (db.maxBulk / len(table.row)) * len(table.row)
+	if len(table.row) > db.maxBulk {
+		table.maxCap = len(table.row)
+	} else {
+		table.maxCap = (db.maxBulk / len(table.row)) * len(table.row)
+	}
 	bulk := make([]interface{}, 0, table.maxCap)
 
 	preRows := reader.PreReadRow()
