@@ -31,7 +31,7 @@ type TRDSQL struct {
 // NewTRDSQL returns a new TRDSQL structure.
 func NewTRDSQL(im Importer, ex Exporter) *TRDSQL {
 	return &TRDSQL{
-		Driver:   "sqlite3",
+		Driver:   DefaultDriver,
 		Dsn:      "",
 		Importer: im,
 		Exporter: ex,
@@ -92,11 +92,11 @@ const (
 	YAML
 
 	// import
-	// Tab-Separated Values format.
+	// Tab-Separated Values format. Format using go standard CSV library.
 	TSV
 
 	// import
-	// Pipe-Separated Values format.
+	// Pipe-Separated Values format. Format using go standard CSV library.
 	PSV
 )
 
@@ -149,8 +149,8 @@ func (trd *TRDSQL) ExecContext(ctx context.Context, sql string) error {
 	}
 
 	defer func() {
-		if deferr := db.Disconnect(); deferr != nil {
-			log.Printf("disconnect: %s", deferr)
+		if deferErr := db.Disconnect(); deferErr != nil {
+			log.Printf("disconnect: %s", deferErr)
 		}
 	}()
 
